@@ -22,6 +22,7 @@
 #include "sebie_helpers.h"
 #include "sebie_view.h"
 #include "sebie_gtk_helpers.h"
+#include "sebie_config.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <stdlib.h>
@@ -136,6 +137,7 @@ sebie_update_view(struct sebie_s *sebie)
   }
 
   sebie->dirty_tags = 0;
+  save_sebie_config(sebie);
 }
 
 
@@ -226,6 +228,7 @@ sebie_update_file_list(struct sebie_s *sebie)
 {
   GError *error = NULL;
   GDir *gdir;
+  save_sebie_config(sebie);
   sebie_file_list_clear(sebie);
   if ((gdir = g_dir_open(sebie->model.input_path, 0, &error)) == NULL) {
     return;
@@ -262,12 +265,45 @@ rotate_scaled(struct sebie_s *sebie, int direction)
 }
 
 
+void
+save_sebie_config(struct sebie_s *sebie)
+{
+  if (sebie->model_tags) {
+    sebie_config_spec config_spec[] = {
+      { "InputPath",  CONFIG_STRING, &sebie->model.input_path, "" },
+      { "InputRegEx", CONFIG_STRING, &sebie->model.input_regex, "\\([0-9]*\\).jpg" },
+      { "OutputFormat", CONFIG_STRING, &sebie->model.output_format, "Image%s.jpg" },
+      { NULL, CONFIG_END, NULL, 0}
+    };
+  
+    sebie_write_config(sebie->config_file, config_spec);
+    sebie->model_tags = 0;
+  }
+}
+
+
 void
 init_sebie_model(struct sebie_s *sebie)
 {
-  sebie->model.input_path  = g_strdup("");
-  sebie->model.input_regex = g_strdup("Image\\([0-9]*\\).jpg");
-  sebie->model.output_format = g_strdup("NewImage%s.jpg");
+  char *homedir;
+  char buf[PATH_MAX];
+  
+  if ((homedir = getenv("HOME")) != NULL) {
+    snprintf(buf, PATH_MAX, "%s/%s", homedir, ".sebieconf");
+    sebie->config_file = g_strdup(buf);
+  } else {
+    sebie->config_file = g_strdup(".sebieconf");
+  }
+  
+  sebie_config_spec config_spec[] = {
+    { "InputPath",  CONFIG_STRING, &sebie->model.input_path, "" },
+    { "InputRegEx", CONFIG_STRING, &sebie->model.input_regex, "\\([0-9]*\\).jpg" },
+    { "OutputFormat", CONFIG_STRING, &sebie->model.output_format, "Image%s.jpg" },
+    { NULL, CONFIG_END, NULL, 0}
+  };
+  
+  sebie_read_config(sebie->config_file, config_spec);
+
   sebie->model.input_file_path = NULL;
   sebie->model.output_file_path = NULL;
 
@@ -285,7 +321,7 @@ init_sebie_model(struct sebie_s *sebie)
   
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC;
 
-  sebie->model.statusbar_text = strdup("   SeBIE  (c) 2002 by Peter.Seiderer@ciselant.de");
+  sebie->model.statusbar_text = strdup("   SeBIE  (C) 2003 by Peter.Seiderer@ciselant.de");
   sebie->dirty_tags |= SEBIE_UPDATE_STATUS_BAR;
 }
 
