@@ -46,6 +46,12 @@ typedef enum sebie_dirty_tag_e {
   SEBIE_UPDATE_STATUS_BAR       = 128
 } sebie_dirty_tag;
 
+typedef enum sebie_model_tag_e {
+  SEBIE_MODEL_INPUT_PATH       =   1,
+  SEBIE_MODEL_INPUT_REGEX      =   2,
+  SEBIE_MODEL_OUTPUT_FORMAT    =   4
+} sebie_model_tag;
+
 typedef enum sebie_mouse_click_e {
   SEBIE_NOT_CLICKED      = 0,
   SEBIE_RESIZE_SELECTION = 1, 
@@ -130,9 +136,16 @@ typedef struct sebie_s {
   sebie_view  view;
   sebie_model model;
   sebie_dirty_tag dirty_tags;
+  sebie_model_tag model_tags;
+  char *config_file;
 } sebie;
 
 
+void sebie_update_view(struct sebie_s *sebie);
+void sebie_update_file_list(struct sebie_s *sebie);
+void rotate_scaled(struct sebie_s *sebie, int direction);
+void save_sebie_config(struct sebie_s *sebie);
+
 /*
  * Standard gettext macros.
  */
