@@ -63,10 +63,8 @@ on_entry_input_path_changed (GtkEditable *editable,
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
   G_CONST_RETURN gchar *input_path = gtk_entry_get_text(GTK_ENTRY(editable));
-  if (sebie->model.input_path != NULL) {
-    g_free(sebie->model.input_path);
-  }
-  sebie->model.input_path = g_strdup(input_path);
+  sebie_set_string(&sebie->model.input_path, input_path);
+  sebie->model_tags |= SEBIE_MODEL_INPUT_PATH;
   sebie_update_file_list(sebie);
 }
 
@@ -76,11 +74,12 @@ on_entry_input_regex_changed (GtkEditable *editable,
 			     gpointer    user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
-  G_CONST_RETURN gchar *regex_str = gtk_entry_get_text(GTK_ENTRY(editable));
-  printf("regex_str = %s\n", regex_str);
-  
+  G_CONST_RETURN gchar *input_regex = gtk_entry_get_text(GTK_ENTRY(editable));
+  printf("input_regex = %s\n", input_regex);
+  sebie_set_string(&sebie->model.input_regex, input_regex);
+  sebie->model_tags |= SEBIE_MODEL_INPUT_REGEX;
   int err;
-  if ((err = regcomp(&sebie->model.regex, regex_str, 0)) != 0) {
+  if ((err = regcomp(&sebie->model.regex, input_regex, 0)) != 0) {
     char buf[256];
     regerror(err, &sebie->model.regex, buf, 256);
     fprintf(stderr, "Error: regcomp failed (%s)\n", buf);
@@ -97,6 +96,8 @@ on_entry_output_format_changed (GtkEditable *editable,
   G_CONST_RETURN gchar *output_format = gtk_entry_get_text(GTK_ENTRY(editable));
   printf("output_format = %s\n", output_format);
   sebie_set_string(&sebie->model.output_format, output_format);
+  sebie->model_tags |= SEBIE_MODEL_OUTPUT_FORMAT;
+  save_sebie_config(sebie);
 }
 
 void
