@@ -22,7 +22,7 @@
 
 
 void
-sebie_set_string(gchar **old_text, gchar *new_text)
+sebie_set_string(gchar **old_text, const gchar *new_text)
 {
   if (*old_text != NULL) {
     g_free(*old_text);
